@@ -122,25 +122,29 @@ PrintPreview.start = function(initialAction, instance) {
         }
     }
 
-    var bbPaper = Print.getPaperBox(doc);
-    bbPaper.growXY(bbPaper.getWidth()/100, bbPaper.getHeight()/100);
-    var bbDoc = doc.getBoundingBox();
-    var positionAccepted = doc.getVariable("PageSettings/PositionAccepted");
-    // check if paper contains drawing:
-    if (!bbPaper.containsBox(bbDoc) && !positionAccepted) {
-        var initialZoom = appWin.property("PrintPreview/InitialZoom");
-        if (initialZoom!=="View") {
-            var ret = QMessageBox.warning(appWin,
-                qsTr("Auto fit"),
-                qsTr("Auto fit drawing to paper?"),
-                buttons);
-            // workaround for Qt keyboard focus bug:
-            appWin.activateWindow();
-            if (ret===QMessageBox.Yes) {
-                appWin.setProperty("PrintPreview/InitialZoom", "Auto");
-            }
-            else {
-                doc.setVariable("PageSettings/PositionAccepted", true);
+    // don't apply global scale for layout blocks:
+    var blockId = doc.getCurrentBlockId();
+    if (!doc.isLayoutBlock(blockId) || blockId===doc.getModelSpaceBlockId()) {
+        var bbPaper = Print.getPaperBox(doc);
+        bbPaper.growXY(bbPaper.getWidth()/100, bbPaper.getHeight()/100);
+        var bbDoc = doc.getBoundingBox();
+        var positionAccepted = doc.getVariable("PageSettings/PositionAccepted");
+        // check if paper contains drawing:
+        if (!bbPaper.containsBox(bbDoc) && !positionAccepted) {
+            var initialZoom = appWin.property("PrintPreview/InitialZoom");
+            if (initialZoom!=="View" && initialZoom!=="Box") {
+                var ret = QMessageBox.warning(appWin,
+                    qsTr("Auto fit"),
+                    qsTr("Auto fit drawing to paper?"),
+                    buttons);
+                // workaround for Qt keyboard focus bug:
+                appWin.activateWindow();
+                if (ret===QMessageBox.Yes) {
+                    appWin.setProperty("PrintPreview/InitialZoom", "Auto");
+                }
+                else {
+                    doc.setVariable("PageSettings/PositionAccepted", true);
+                }
             }
         }
     }
@@ -242,7 +246,7 @@ PrintPreviewImpl.prototype.beginEvent = function() {
     var appWin = RMainWindowQt.getMainWindow();
     var initialZoom = appWin.property("PrintPreview/InitialZoom");
 
-    if (initialZoom==="View") {
+    if (initialZoom==="View" || initialZoom==="Box") {
         this.savedScale = Print.getScale(this.getDocument());
         this.savedOffset = Print.getOffset(this.getDocument());
         this.savedColumns = Print.getColumns(this.getDocument());
@@ -300,6 +304,17 @@ PrintPreviewImpl.prototype.beginEvent = function() {
 
         appWin.setProperty("PrintPreview/InitialZoom", "Stored");
     }
+    else if (initialZoom==="Box") {
+        //Print.setColumns(di, 1);
+        //Print.setRows(di, 1);
+        var x1 = appWin.property("PrintPreview/InitialZoomBoxX1");
+        var y1 = appWin.property("PrintPreview/InitialZoomBoxY1");
+        var x2 = appWin.property("PrintPreview/InitialZoomBoxX2");
+        var y2 = appWin.property("PrintPreview/InitialZoomBoxY2");
+        this.slotAutoFitBox(new RBox(x1,y1, x2,y2));
+
+        appWin.setProperty("PrintPreview/InitialZoom", "Stored");
+    }
 
     if (this.initialAction==="Print") {
         this.slotPrint();
@@ -584,8 +599,8 @@ PrintPreviewImpl.prototype.showUiOptions = function(resume) {
 /**
  * Initializes the scale combo box in the options toolbar with defaults.
  */
-PrintPreviewImpl.prototype.initUiOptions = function(resume, optionsToolBar) {
-    EAction.prototype.initUiOptions.call(this, resume, optionsToolBar);
+PrintPreviewImpl.prototype.initUiOptions = function(resume, optionsToolBar, forDialog) {
+    EAction.prototype.initUiOptions.call(this, resume, optionsToolBar, forDialog);
     this.initScaleCombo();
 };
 
